"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// NOTE: nodom.HTMLElement defines a subset of properties and functions of
// the browser's HTMLElement, that's why we use it here.
const nodom_1 = require("nodom");
exports.HTMLElement = nodom_1.HTMLElement;
/**
 * Returns a function for building `HTMLElement`s.
 *
 * @param {function} createElement A function that creates a new `HTMLElement`
 *   (e.g. `document.createElement.bind(document)`).
 * @param {string} classPrefix The prefix to be used for all CSS class names
 *   except `lang-*`. Default is `nb-`.
 */
exports.default = (createElement, classPrefix = 'nb-') => {
    const prefixClassName = (name) => name.startsWith('lang-') ? name : classPrefix + name;
    return (tag, classesOrAttrs, childrenOrHTML) => {
        const el = createElement(tag);
        if (Array.isArray(classesOrAttrs)) {
            el.className = classesOrAttrs.map(prefixClassName).join(' ');
        }
        else if (classesOrAttrs) {
            for (const [key, val] of Object.entries(classesOrAttrs)) {
                if (key === 'class') {
                    el.className = val.split(' ').map(prefixClassName).join(' ');
                }
                else {
                    el.setAttribute(key, val);
                }
            }
        }
        if (Array.isArray(childrenOrHTML)) {
            childrenOrHTML.forEach(e => el.appendChild(e));
        }
        else if (childrenOrHTML) {
            el.innerHTML = childrenOrHTML;
        }
        return el;
    };
};
//# sourceMappingURL=elementCreator.js.map