"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const highlightjs_1 = __importDefault(require("highlightjs"));
const katex_1 = __importDefault(require("katex"));
const marked_1 = __importDefault(require("marked"));
const mathExtractor_1 = require("./mathExtractor");
function highlight(code, lang) {
    return highlightjs_1.default.getLanguage(lang)
        ? highlightjs_1.default.highlight(lang, code, true).value
        : code;
}
/**
 * Returns a pre-configured marked parser with math support (using KaTeX)
 * and code highlighter (highlight.js).
 *
 * @param {MarkedOptions} markedOpts Options for the marked Markdown renderer.
 * @param {KatexOptions} katexOpts Options for the KaTeX math renderer.
 */
exports.default = (markedOpts = {}, katexOpts = {}) => {
    markedOpts = { highlight, ...markedOpts };
    katexOpts = { strict: false, throwOnError: false, ...katexOpts };
    /**
     * Converts the given *markdown* into HTML.
     */
    return (markdown) => {
        const [text, math] = mathExtractor_1.extractMath(markdown);
        const html = marked_1.default.parse(text, markedOpts);
        const mathHtml = math.map(({ value, displayMode }) => {
            return katex_1.default.renderToString(value, { ...katexOpts, displayMode });
        });
        return mathExtractor_1.restoreMath(html, mathHtml);
    };
};
//# sourceMappingURL=markdownRenderer.js.map